@@ -32,7 +32,9 @@ from google.protobuf import empty_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-asset",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-asset",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -81,6 +83,7 @@ class AssetServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -122,7 +125,9 @@ class AssetServiceTransport(abc.ABC):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.export_assets: gapic_v1.method.wrap_method(
-                self.export_assets, default_timeout=60.0, client_info=client_info,
+                self.export_assets,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.list_assets: gapic_v1.method.wrap_method(
                 self.list_assets,
@@ -155,7 +160,9 @@ class AssetServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_feed: gapic_v1.method.wrap_method(
-                self.create_feed, default_timeout=60.0, client_info=client_info,
+                self.create_feed,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.get_feed: gapic_v1.method.wrap_method(
                 self.get_feed,
@@ -188,7 +195,9 @@ class AssetServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.update_feed: gapic_v1.method.wrap_method(
-                self.update_feed, default_timeout=60.0, client_info=client_info,
+                self.update_feed,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.delete_feed: gapic_v1.method.wrap_method(
                 self.delete_feed,
@@ -253,16 +262,48 @@ class AssetServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.analyze_move: gapic_v1.method.wrap_method(
-                self.analyze_move, default_timeout=None, client_info=client_info,
+                self.analyze_move,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.create_saved_query: gapic_v1.method.wrap_method(
+                self.create_saved_query,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_saved_query: gapic_v1.method.wrap_method(
+                self.get_saved_query,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_saved_queries: gapic_v1.method.wrap_method(
+                self.list_saved_queries,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.update_saved_query: gapic_v1.method.wrap_method(
+                self.update_saved_query,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.delete_saved_query: gapic_v1.method.wrap_method(
+                self.delete_saved_query,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.batch_get_effective_iam_policies: gapic_v1.method.wrap_method(
+                self.batch_get_effective_iam_policies,
+                default_timeout=None,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -408,5 +449,69 @@ class AssetServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def create_saved_query(
+        self,
+    ) -> Callable[
+        [asset_service.CreateSavedQueryRequest],
+        Union[asset_service.SavedQuery, Awaitable[asset_service.SavedQuery]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_saved_query(
+        self,
+    ) -> Callable[
+        [asset_service.GetSavedQueryRequest],
+        Union[asset_service.SavedQuery, Awaitable[asset_service.SavedQuery]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def list_saved_queries(
+        self,
+    ) -> Callable[
+        [asset_service.ListSavedQueriesRequest],
+        Union[
+            asset_service.ListSavedQueriesResponse,
+            Awaitable[asset_service.ListSavedQueriesResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def update_saved_query(
+        self,
+    ) -> Callable[
+        [asset_service.UpdateSavedQueryRequest],
+        Union[asset_service.SavedQuery, Awaitable[asset_service.SavedQuery]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def delete_saved_query(
+        self,
+    ) -> Callable[
+        [asset_service.DeleteSavedQueryRequest],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def batch_get_effective_iam_policies(
+        self,
+    ) -> Callable[
+        [asset_service.BatchGetEffectiveIamPoliciesRequest],
+        Union[
+            asset_service.BatchGetEffectiveIamPoliciesResponse,
+            Awaitable[asset_service.BatchGetEffectiveIamPoliciesResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("AssetServiceTransport",)
