@@ -78,11 +78,30 @@ class TemporalAsset(proto.Message):
         DOES_NOT_EXIST = 3
         DELETED = 4
 
-    window = proto.Field(proto.MESSAGE, number=1, message="TimeWindow",)
-    deleted = proto.Field(proto.BOOL, number=2,)
-    asset = proto.Field(proto.MESSAGE, number=3, message="Asset",)
-    prior_asset_state = proto.Field(proto.ENUM, number=4, enum=PriorAssetState,)
-    prior_asset = proto.Field(proto.MESSAGE, number=5, message="Asset",)
+    window = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="TimeWindow",
+    )
+    deleted = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    asset = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Asset",
+    )
+    prior_asset_state = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=PriorAssetState,
+    )
+    prior_asset = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="Asset",
+    )
 
 
 class TimeWindow(proto.Message):
@@ -97,8 +116,16 @@ class TimeWindow(proto.Message):
             instead.
     """
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class Asset(proto.Message):
@@ -177,9 +204,14 @@ class Asset(proto.Message):
             topic <https://cloud.google.com/compute/docs/instances/os-inventory-management>`__
             for more information.
         related_assets (google.cloud.asset_v1.types.RelatedAssets):
+            DEPRECATED. This field only presents for the
+            purpose of backward-compatibility. The server
+            will never generate responses with this field.
             The related assets of the asset of one
             relationship type. One asset only represents one
             type of relationship.
+        related_asset (google.cloud.asset_v1.types.RelatedAsset):
+            One related asset of the current asset.
         ancestors (Sequence[str]):
             The ancestry path of an asset in Google Cloud `resource
             hierarchy <https://cloud.google.com/resource-manager/docs/cloud-platform-resource-hierarchy>`__,
@@ -194,14 +226,32 @@ class Asset(proto.Message):
     """
 
     update_time = proto.Field(
-        proto.MESSAGE, number=11, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=11,
+        message=timestamp_pb2.Timestamp,
+    )
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    asset_type = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Resource",
+    )
+    iam_policy = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=policy_pb2.Policy,
     )
-    name = proto.Field(proto.STRING, number=1,)
-    asset_type = proto.Field(proto.STRING, number=2,)
-    resource = proto.Field(proto.MESSAGE, number=3, message="Resource",)
-    iam_policy = proto.Field(proto.MESSAGE, number=4, message=policy_pb2.Policy,)
     org_policy = proto.RepeatedField(
-        proto.MESSAGE, number=6, message=orgpolicy_pb2.Policy,
+        proto.MESSAGE,
+        number=6,
+        message=orgpolicy_pb2.Policy,
     )
     access_policy = proto.Field(
         proto.MESSAGE,
@@ -221,9 +271,25 @@ class Asset(proto.Message):
         oneof="access_context_policy",
         message=service_perimeter_pb2.ServicePerimeter,
     )
-    os_inventory = proto.Field(proto.MESSAGE, number=12, message=Inventory,)
-    related_assets = proto.Field(proto.MESSAGE, number=13, message="RelatedAssets",)
-    ancestors = proto.RepeatedField(proto.STRING, number=10,)
+    os_inventory = proto.Field(
+        proto.MESSAGE,
+        number=12,
+        message=Inventory,
+    )
+    related_assets = proto.Field(
+        proto.MESSAGE,
+        number=13,
+        message="RelatedAssets",
+    )
+    related_asset = proto.Field(
+        proto.MESSAGE,
+        number=15,
+        message="RelatedAsset",
+    )
+    ancestors = proto.RepeatedField(
+        proto.STRING,
+        number=10,
+    )
 
 
 class Resource(proto.Message):
@@ -275,17 +341,42 @@ class Resource(proto.Message):
             https://cloud.google.com/about/locations/.
     """
 
-    version = proto.Field(proto.STRING, number=1,)
-    discovery_document_uri = proto.Field(proto.STRING, number=2,)
-    discovery_name = proto.Field(proto.STRING, number=3,)
-    resource_url = proto.Field(proto.STRING, number=4,)
-    parent = proto.Field(proto.STRING, number=5,)
-    data = proto.Field(proto.MESSAGE, number=6, message=struct_pb2.Struct,)
-    location = proto.Field(proto.STRING, number=8,)
+    version = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    discovery_document_uri = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    discovery_name = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    resource_url = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    parent = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    data = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=struct_pb2.Struct,
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=8,
+    )
 
 
 class RelatedAssets(proto.Message):
-    r"""The detailed related assets with the ``relationship_type``.
+    r"""DEPRECATED. This message only presents for the purpose of
+    backward-compatibility. The server will never populate this message
+    in responses. The detailed related assets with the
+    ``relationship_type``.
 
     Attributes:
         relationship_attributes (google.cloud.asset_v1.types.RelationshipAttributes):
@@ -295,13 +386,21 @@ class RelatedAssets(proto.Message):
     """
 
     relationship_attributes = proto.Field(
-        proto.MESSAGE, number=1, message="RelationshipAttributes",
+        proto.MESSAGE,
+        number=1,
+        message="RelationshipAttributes",
+    )
+    assets = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="RelatedAsset",
     )
-    assets = proto.RepeatedField(proto.MESSAGE, number=2, message="RelatedAsset",)
 
 
 class RelationshipAttributes(proto.Message):
-    r"""The relationship attributes which include ``type``,
+    r"""DEPRECATED. This message only presents for the purpose of
+    backward-compatibility. The server will never populate this message
+    in responses. The relationship attributes which include ``type``,
     ``source_resource_type``, ``target_resource_type`` and ``action``.
 
     Attributes:
@@ -319,15 +418,27 @@ class RelationshipAttributes(proto.Message):
             ``attaches``
     """
 
-    type_ = proto.Field(proto.STRING, number=4,)
-    source_resource_type = proto.Field(proto.STRING, number=1,)
-    target_resource_type = proto.Field(proto.STRING, number=2,)
-    action = proto.Field(proto.STRING, number=3,)
+    type_ = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    source_resource_type = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    target_resource_type = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    action = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class RelatedAsset(proto.Message):
-    r"""An asset identify in Google Cloud which contains its name, type and
-    ancestors. An asset can be any resource in the Google Cloud
+    r"""An asset identifier in Google Cloud which contains its name, type
+    and ancestors. An asset can be any resource in the Google Cloud
     `resource
     hierarchy <https://cloud.google.com/resource-manager/docs/cloud-platform-resource-hierarchy>`__,
     a resource outside the Google Cloud resource hierarchy (such as
@@ -360,11 +471,27 @@ class RelatedAsset(proto.Message):
 
             Example:
             ``["projects/123456789", "folders/5432", "organizations/1234"]``
+        relationship_type (str):
+            The unique identifier of the relationship type. Example:
+            ``INSTANCE_TO_INSTANCEGROUP``
     """
 
-    asset = proto.Field(proto.STRING, number=1,)
-    asset_type = proto.Field(proto.STRING, number=2,)
-    ancestors = proto.RepeatedField(proto.STRING, number=3,)
+    asset = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    asset_type = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    ancestors = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    relationship_type = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ResourceSearchResult(proto.Message):
@@ -425,7 +552,7 @@ class ResourceSearchResult(proto.Message):
                search request.
         display_name (str):
             The display name of this resource. This field is available
-            only when the resource's proto contains it.
+            only when the resource's Protobuf contains it.
 
             To search against the ``display_name``:
 
@@ -434,7 +561,7 @@ class ResourceSearchResult(proto.Message):
         description (str):
             One or more paragraphs of text description of this resource.
             Maximum length could be up to 1M bytes. This field is
-            available only when the resource's proto contains it.
+            available only when the resource's Protobuf contains it.
 
             To search against the ``description``:
 
@@ -444,18 +571,18 @@ class ResourceSearchResult(proto.Message):
         location (str):
             Location can be ``global``, regional like ``us-east1``, or
             zonal like ``us-west1-b``. This field is available only when
-            the resource's proto contains it.
+            the resource's Protobuf contains it.
 
             To search against the ``location``:
 
             -  use a field query. Example: ``location:us-west*``
             -  use a free text query. Example: ``us-west*``
-        labels (Sequence[google.cloud.asset_v1.types.ResourceSearchResult.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels associated with this resource. See `Labelling and
             grouping GCP
             resources <https://cloud.google.com/blog/products/gcp/labelling-and-grouping-your-google-cloud-platform-resources>`__
             for more information. This field is available only when the
-            resource's proto contains it.
+            resource's Protobuf contains it.
 
             To search against the ``labels``:
 
@@ -474,7 +601,7 @@ class ResourceSearchResult(proto.Message):
             resources. See `Labelling GCP
             resources <https://cloud.google.com/blog/products/gcp/labelling-and-grouping-your-google-cloud-platform-resources>`__
             for more information. This field is available only when the
-            resource's proto contains it.
+            resource's Protobuf contains it.
 
             To search against the ``network_tags``:
 
@@ -482,11 +609,11 @@ class ResourceSearchResult(proto.Message):
             -  use a free text query. Example: ``internal``
         kms_key (str):
             The Cloud KMS
-            `CryptoKey <https://cloud.google.com/kms/docs/reference/rest/v1/projects.locations.keyRings.cryptoKeys?hl=en>`__
+            `CryptoKey <https://cloud.google.com/kms/docs/reference/rest/v1/projects.locations.keyRings.cryptoKeys>`__
             name or
-            `CryptoKeyVersion <https://cloud.google.com/kms/docs/reference/rest/v1/projects.locations.keyRings.cryptoKeys.cryptoKeyVersions?hl=en>`__
-            name. This field is available only when the resource's proto
-            contains it.
+            `CryptoKeyVersion <https://cloud.google.com/kms/docs/reference/rest/v1/projects.locations.keyRings.cryptoKeys.cryptoKeyVersions>`__
+            name. This field is available only when the resource's
+            Protobuf contains it.
 
             To search against the ``kms_key``:
 
@@ -496,7 +623,7 @@ class ResourceSearchResult(proto.Message):
             The create timestamp of this resource, at which the resource
             was created. The granularity is in seconds. Timestamp.nanos
             will always be 0. This field is available only when the
-            resource's proto contains it.
+            resource's Protobuf contains it.
 
             To search against ``create_time``:
 
@@ -512,7 +639,7 @@ class ResourceSearchResult(proto.Message):
             The last update timestamp of this resource, at which the
             resource was last modified or deleted. The granularity is in
             seconds. Timestamp.nanos will always be 0. This field is
-            available only when the resource's proto contains it.
+            available only when the resource's Protobuf contains it.
 
             To search against ``update_time``:
 
@@ -528,7 +655,7 @@ class ResourceSearchResult(proto.Message):
             The state of this resource. Different resources types have
             different state definitions that are mapped from various
             fields of different resource types. This field is available
-            only when the resource's proto contains it.
+            only when the resource's Protobuf contains it.
 
             Example: If the resource is an instance provided by Compute
             Engine, its state will include PROVISIONING, STAGING,
@@ -593,13 +720,54 @@ class ResourceSearchResult(proto.Message):
             attributes of the attached resources are exposed in
             ``additional_attributes`` field, so as to allow users to
             search on them.
-        relationships (Sequence[google.cloud.asset_v1.types.ResourceSearchResult.RelationshipsEntry]):
+        relationships (Mapping[str, google.cloud.asset_v1.types.RelatedResources]):
             A map of related resources of this resource, keyed by the
             relationship type. A relationship type is in the format of
             {SourceType}*{ACTION}*\ {DestType}. Example:
             ``DISK_TO_INSTANCE``, ``DISK_TO_NETWORK``,
             ``INSTANCE_TO_INSTANCEGROUP``. See `supported relationship
             types <https://cloud.google.com/asset-inventory/docs/supported-asset-types#supported_relationship_types>`__.
+        tag_keys (Sequence[str]):
+            TagKey namespaced names, in the format of
+            {ORG_ID}/{TAG_KEY_SHORT_NAME}. To search against the
+            ``tagKeys``:
+
+            -  use a field query. Example:
+
+               -  ``tagKeys:"123456789/env*"``
+               -  ``tagKeys="123456789/env"``
+               -  ``tagKeys:"env"``
+
+            -  use a free text query. Example:
+
+               -  ``env``
+        tag_values (Sequence[str]):
+            TagValue namespaced names, in the format of
+            {ORG_ID}/{TAG_KEY_SHORT_NAME}/{TAG_VALUE_SHORT_NAME}. To
+            search against the ``tagValues``:
+
+            -  use a field query. Example:
+
+               -  ``tagValues:"env"``
+               -  ``tagValues:"env/prod"``
+               -  ``tagValues:"123456789/env/prod*"``
+               -  ``tagValues="123456789/env/prod"``
+
+            -  use a free text query. Example:
+
+               -  ``prod``
+        tag_value_ids (Sequence[str]):
+            TagValue IDs, in the format of tagValues/{TAG_VALUE_ID}. To
+            search against the ``tagValueIds``:
+
+            -  use a field query. Example:
+
+               -  ``tagValueIds:"456"``
+               -  ``tagValueIds="tagValues/456"``
+
+            -  use a free text query. Example:
+
+               -  ``456``
         parent_asset_type (str):
             The type of this resource's immediate parent, if there is
             one.
@@ -612,38 +780,106 @@ class ResourceSearchResult(proto.Message):
                ``cloudresourcemanager.googleapis.com/Project``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    asset_type = proto.Field(proto.STRING, number=2,)
-    project = proto.Field(proto.STRING, number=3,)
-    folders = proto.RepeatedField(proto.STRING, number=17,)
-    organization = proto.Field(proto.STRING, number=18,)
-    display_name = proto.Field(proto.STRING, number=4,)
-    description = proto.Field(proto.STRING, number=5,)
-    location = proto.Field(proto.STRING, number=6,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=7,)
-    network_tags = proto.RepeatedField(proto.STRING, number=8,)
-    kms_key = proto.Field(proto.STRING, number=10,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    asset_type = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    project = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    folders = proto.RepeatedField(
+        proto.STRING,
+        number=17,
+    )
+    organization = proto.Field(
+        proto.STRING,
+        number=18,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=7,
+    )
+    network_tags = proto.RepeatedField(
+        proto.STRING,
+        number=8,
+    )
+    kms_key = proto.Field(
+        proto.STRING,
+        number=10,
+    )
     create_time = proto.Field(
-        proto.MESSAGE, number=11, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=11,
+        message=timestamp_pb2.Timestamp,
     )
     update_time = proto.Field(
-        proto.MESSAGE, number=12, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=12,
+        message=timestamp_pb2.Timestamp,
+    )
+    state = proto.Field(
+        proto.STRING,
+        number=13,
     )
-    state = proto.Field(proto.STRING, number=13,)
     additional_attributes = proto.Field(
-        proto.MESSAGE, number=9, message=struct_pb2.Struct,
+        proto.MESSAGE,
+        number=9,
+        message=struct_pb2.Struct,
+    )
+    parent_full_resource_name = proto.Field(
+        proto.STRING,
+        number=19,
     )
-    parent_full_resource_name = proto.Field(proto.STRING, number=19,)
     versioned_resources = proto.RepeatedField(
-        proto.MESSAGE, number=16, message="VersionedResource",
+        proto.MESSAGE,
+        number=16,
+        message="VersionedResource",
     )
     attached_resources = proto.RepeatedField(
-        proto.MESSAGE, number=20, message="AttachedResource",
+        proto.MESSAGE,
+        number=20,
+        message="AttachedResource",
     )
     relationships = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=21, message="RelatedResources",
+        proto.STRING,
+        proto.MESSAGE,
+        number=21,
+        message="RelatedResources",
+    )
+    tag_keys = proto.RepeatedField(
+        proto.STRING,
+        number=23,
+    )
+    tag_values = proto.RepeatedField(
+        proto.STRING,
+        number=25,
+    )
+    tag_value_ids = proto.RepeatedField(
+        proto.STRING,
+        number=26,
+    )
+    parent_asset_type = proto.Field(
+        proto.STRING,
+        number=103,
     )
-    parent_asset_type = proto.Field(proto.STRING, number=103,)
 
 
 class VersionedResource(proto.Message):
@@ -672,8 +908,15 @@ class VersionedResource(proto.Message):
             ``https://cloud.google.com/asset-inventory/docs/supported-asset-types#searchable_asset_types``
     """
 
-    version = proto.Field(proto.STRING, number=1,)
-    resource = proto.Field(proto.MESSAGE, number=2, message=struct_pb2.Struct,)
+    version = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=struct_pb2.Struct,
+    )
 
 
 class AttachedResource(proto.Message):
@@ -698,9 +941,14 @@ class AttachedResource(proto.Message):
             migration.
     """
 
-    asset_type = proto.Field(proto.STRING, number=1,)
+    asset_type = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     versioned_resources = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="VersionedResource",
+        proto.MESSAGE,
+        number=3,
+        message="VersionedResource",
     )
 
 
@@ -714,7 +962,9 @@ class RelatedResources(proto.Message):
     """
 
     related_resources = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="RelatedResource",
+        proto.MESSAGE,
+        number=1,
+        message="RelatedResource",
     )
 
 
@@ -730,8 +980,14 @@ class RelatedResource(proto.Message):
             ``//compute.googleapis.com/projects/my_proj_123/zones/instance/instance123``
     """
 
-    asset_type = proto.Field(proto.STRING, number=1,)
-    full_resource_name = proto.Field(proto.STRING, number=2,)
+    asset_type = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    full_resource_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class IamPolicySearchResult(proto.Message):
@@ -820,7 +1076,7 @@ class IamPolicySearchResult(proto.Message):
         r"""Explanation about the IAM policy search result.
 
         Attributes:
-            matched_permissions (Sequence[google.cloud.asset_v1.types.IamPolicySearchResult.Explanation.MatchedPermissionsEntry]):
+            matched_permissions (Mapping[str, google.cloud.asset_v1.types.IamPolicySearchResult.Explanation.Permissions]):
                 The map from roles to their included permissions that match
                 the permission query (i.e., a query containing
                 ``policy.role.permissions:``). Example: if query
@@ -842,7 +1098,10 @@ class IamPolicySearchResult(proto.Message):
                     ``compute.disk.get``.
             """
 
-            permissions = proto.RepeatedField(proto.STRING, number=1,)
+            permissions = proto.RepeatedField(
+                proto.STRING,
+                number=1,
+            )
 
         matched_permissions = proto.MapField(
             proto.STRING,
@@ -851,13 +1110,36 @@ class IamPolicySearchResult(proto.Message):
             message="IamPolicySearchResult.Explanation.Permissions",
         )
 
-    resource = proto.Field(proto.STRING, number=1,)
-    asset_type = proto.Field(proto.STRING, number=5,)
-    project = proto.Field(proto.STRING, number=2,)
-    folders = proto.RepeatedField(proto.STRING, number=6,)
-    organization = proto.Field(proto.STRING, number=7,)
-    policy = proto.Field(proto.MESSAGE, number=3, message=policy_pb2.Policy,)
-    explanation = proto.Field(proto.MESSAGE, number=4, message=Explanation,)
+    resource = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    asset_type = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    project = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    folders = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
+    organization = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    policy = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=policy_pb2.Policy,
+    )
+    explanation = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=Explanation,
+    )
 
 
 class IamPolicyAnalysisState(proto.Message):
@@ -880,8 +1162,15 @@ class IamPolicyAnalysisState(proto.Message):
             of failure.
     """
 
-    code = proto.Field(proto.ENUM, number=1, enum=code_pb2.Code,)
-    cause = proto.Field(proto.STRING, number=2,)
+    code = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=code_pb2.Code,
+    )
+    cause = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ConditionEvaluation(proto.Message):
@@ -899,7 +1188,11 @@ class ConditionEvaluation(proto.Message):
         FALSE = 2
         CONDITIONAL = 3
 
-    evaluation_value = proto.Field(proto.ENUM, number=1, enum=EvaluationValue,)
+    evaluation_value = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=EvaluationValue,
+    )
 
 
 class IamPolicyAnalysisResult(proto.Message):
@@ -942,9 +1235,14 @@ class IamPolicyAnalysisResult(proto.Message):
                 The analysis state of this resource.
         """
 
-        full_resource_name = proto.Field(proto.STRING, number=1,)
+        full_resource_name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
         analysis_state = proto.Field(
-            proto.MESSAGE, number=2, message="IamPolicyAnalysisState",
+            proto.MESSAGE,
+            number=2,
+            message="IamPolicyAnalysisState",
         )
 
     class Access(proto.Message):
@@ -970,10 +1268,20 @@ class IamPolicyAnalysisResult(proto.Message):
                 The analysis state of this access.
         """
 
-        role = proto.Field(proto.STRING, number=1, oneof="oneof_access",)
-        permission = proto.Field(proto.STRING, number=2, oneof="oneof_access",)
+        role = proto.Field(
+            proto.STRING,
+            number=1,
+            oneof="oneof_access",
+        )
+        permission = proto.Field(
+            proto.STRING,
+            number=2,
+            oneof="oneof_access",
+        )
         analysis_state = proto.Field(
-            proto.MESSAGE, number=3, message="IamPolicyAnalysisState",
+            proto.MESSAGE,
+            number=3,
+            message="IamPolicyAnalysisState",
         )
 
     class Identity(proto.Message):
@@ -997,9 +1305,14 @@ class IamPolicyAnalysisResult(proto.Message):
                 The analysis state of this identity.
         """
 
-        name = proto.Field(proto.STRING, number=1,)
+        name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
         analysis_state = proto.Field(
-            proto.MESSAGE, number=2, message="IamPolicyAnalysisState",
+            proto.MESSAGE,
+            number=2,
+            message="IamPolicyAnalysisState",
         )
 
     class Edge(proto.Message):
@@ -1016,8 +1329,14 @@ class IamPolicyAnalysisResult(proto.Message):
                 node or an email of an identity.
         """
 
-        source_node = proto.Field(proto.STRING, number=1,)
-        target_node = proto.Field(proto.STRING, number=2,)
+        source_node = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        target_node = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     class AccessControlList(proto.Message):
         r"""An access control list, derived from the above IAM policy binding,
@@ -1068,16 +1387,24 @@ class IamPolicyAnalysisResult(proto.Message):
         """
 
         resources = proto.RepeatedField(
-            proto.MESSAGE, number=1, message="IamPolicyAnalysisResult.Resource",
+            proto.MESSAGE,
+            number=1,
+            message="IamPolicyAnalysisResult.Resource",
         )
         accesses = proto.RepeatedField(
-            proto.MESSAGE, number=2, message="IamPolicyAnalysisResult.Access",
+            proto.MESSAGE,
+            number=2,
+            message="IamPolicyAnalysisResult.Access",
         )
         resource_edges = proto.RepeatedField(
-            proto.MESSAGE, number=3, message="IamPolicyAnalysisResult.Edge",
+            proto.MESSAGE,
+            number=3,
+            message="IamPolicyAnalysisResult.Edge",
         )
         condition_evaluation = proto.Field(
-            proto.MESSAGE, number=4, message="ConditionEvaluation",
+            proto.MESSAGE,
+            number=4,
+            message="ConditionEvaluation",
         )
 
     class IdentityList(proto.Message):
@@ -1106,19 +1433,39 @@ class IamPolicyAnalysisResult(proto.Message):
         """
 
         identities = proto.RepeatedField(
-            proto.MESSAGE, number=1, message="IamPolicyAnalysisResult.Identity",
+            proto.MESSAGE,
+            number=1,
+            message="IamPolicyAnalysisResult.Identity",
         )
         group_edges = proto.RepeatedField(
-            proto.MESSAGE, number=2, message="IamPolicyAnalysisResult.Edge",
+            proto.MESSAGE,
+            number=2,
+            message="IamPolicyAnalysisResult.Edge",
         )
 
-    attached_resource_full_name = proto.Field(proto.STRING, number=1,)
-    iam_binding = proto.Field(proto.MESSAGE, number=2, message=policy_pb2.Binding,)
+    attached_resource_full_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    iam_binding = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=policy_pb2.Binding,
+    )
     access_control_lists = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=AccessControlList,
+        proto.MESSAGE,
+        number=3,
+        message=AccessControlList,
+    )
+    identity_list = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=IdentityList,
+    )
+    fully_explored = proto.Field(
+        proto.BOOL,
+        number=5,
     )
-    identity_list = proto.Field(proto.MESSAGE, number=4, message=IdentityList,)
-    fully_explored = proto.Field(proto.BOOL, number=5,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
