@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -54,7 +54,10 @@ class AssetServiceClientMeta(type):
     _transport_registry["grpc"] = AssetServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = AssetServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[AssetServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[AssetServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -159,10 +162,14 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def access_level_path(access_policy: str, access_level: str,) -> str:
+    def access_level_path(
+        access_policy: str,
+        access_level: str,
+    ) -> str:
         """Returns a fully-qualified access_level string."""
         return "accessPolicies/{access_policy}/accessLevels/{access_level}".format(
-            access_policy=access_policy, access_level=access_level,
+            access_policy=access_policy,
+            access_level=access_level,
         )
 
     @staticmethod
@@ -175,9 +182,13 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def access_policy_path(access_policy: str,) -> str:
+    def access_policy_path(
+        access_policy: str,
+    ) -> str:
         """Returns a fully-qualified access_policy string."""
-        return "accessPolicies/{access_policy}".format(access_policy=access_policy,)
+        return "accessPolicies/{access_policy}".format(
+            access_policy=access_policy,
+        )
 
     @staticmethod
     def parse_access_policy_path(path: str) -> Dict[str, str]:
@@ -191,10 +202,14 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return "*".format()
 
     @staticmethod
-    def service_perimeter_path(access_policy: str, service_perimeter: str,) -> str:
+    def service_perimeter_path(
+        access_policy: str,
+        service_perimeter: str,
+    ) -> str:
         """Returns a fully-qualified service_perimeter string."""
         return "accessPolicies/{access_policy}/servicePerimeters/{service_perimeter}".format(
-            access_policy=access_policy, service_perimeter=service_perimeter,
+            access_policy=access_policy,
+            service_perimeter=service_perimeter,
         )
 
     @staticmethod
@@ -207,7 +222,9 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -220,9 +237,13 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -231,9 +252,13 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -242,9 +267,13 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -253,10 +282,14 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -441,7 +474,6 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         r"""Lists assets with time and resource types and returns
         paged results in response.
 
-
         .. code-block:: python
 
             from google.cloud import asset_v1p5beta1
@@ -498,12 +530,20 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListAssetsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -525,7 +565,9 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-asset",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-asset",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
